@@ -48,8 +48,6 @@ def test_window_kind(expr: nw.Expr, expected: int) -> None:
 def test_misleading_order_by() -> None:
     with pytest.raises(InvalidOperationError):
         nw.col("a").mean().over(order_by="b")
-    with pytest.raises(InvalidOperationError):
-        nw.col("a").rank().over(order_by="b")
 
 
 def test_double_over() -> None:
@@ -77,6 +75,8 @@ def test_head_aggregation() -> None:
 def test_rank_aggregation() -> None:
     with pytest.raises(InvalidOperationError):
         nw.col("a").mean().rank()
+    with pytest.raises(InvalidOperationError):
+        nw.col("a").mean().is_unique()
 
 
 def test_diff_aggregation() -> None:
