@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, Mapping, cast
+from typing import TYPE_CHECKING, Any, cast
 
 import pytest
 from hypothesis import assume, given, strategies as st
@@ -17,6 +17,9 @@ import pandas as pd
 import polars as pl
 import pyarrow as pa
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
 
 @given(
     st.lists(
