@@ -20,11 +20,10 @@ for each attempted `@overload` match.
 from __future__ import annotations
 
 # mypy: disallow-any-generics=false, disable-error-code="var-annotated"
-import sys
 from contextlib import nullcontext as does_not_raise
 from importlib.util import find_spec
 from itertools import chain
-from typing import TYPE_CHECKING, Any, Callable, Iterable, Iterator, Literal, cast
+from typing import TYPE_CHECKING, Any, Callable, Literal, cast
 
 import numpy as np
 import pytest
@@ -35,6 +34,8 @@ from narwhals._utils import Version
 from tests.utils import Constructor, maybe_get_modin_df
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable, Iterator
+
     from _pytest.mark import ParameterSet
     from typing_extensions import assert_type
 
@@ -278,7 +279,6 @@ def test_eager_only_lazy_dask(eager_only: Any, context: Any) -> None:
         assert nw_v1.from_native(dframe, eager_only=eager_only, strict=False) is dframe
 
 
-@pytest.mark.skipif(sys.version_info < (3, 9), reason="too old for sqlframe")
 def test_series_only_sqlframe() -> None:  # pragma: no cover
     pytest.importorskip("sqlframe")
     from sqlframe.duckdb import DuckDBSession
@@ -303,7 +303,6 @@ def test_series_only_sqlframe() -> None:  # pragma: no cover
         ),
     ],
 )
-@pytest.mark.skipif(sys.version_info < (3, 9), reason="too old for sqlframe")
 def test_eager_only_sqlframe(eager_only: Any, context: Any) -> None:  # pragma: no cover
     pytest.importorskip("sqlframe")
     from sqlframe.duckdb import DuckDBSession
